@@ -8,7 +8,9 @@
 #' @section Usage:
 #' \preformatted{
 #' model = Predictor$new(model = NULL, data, y = NULL, class=NULL, 
-#'   predict.fun = function(object, newdata) predict(object, newdata))
+#'   predict.fun = NULL, type = NULL)
+#'   
+#' model$predict(newdata)
 #' }
 #' 
 #' @section Arguments:
@@ -16,9 +18,12 @@
 #' \item{model: }{(any)\cr The machine learning model. Recommended are models from mlr and caret.
 #' Other machine learning with a S3 predict functions work as well, but less robust (e.g. randomForest).}
 #' \item{data: }{(data.frame)\cr The data to be used for analysing the prediction model.}
-#' \item{y: }{(`character(1)` | numeric | factor)\cr The target vector or (preferably) the name of the target column in the \code{data} argument.}
+#' \item{y: }{((`character(1)`) | numeric | factor)\cr The target vector or (preferably) the name of the target column in the \code{data} argument.}
 #' \item{class: }{(`character(1)`)\cr The class column to be returned in case of multiclass output.}
 #' \item{predict.fun: }{(function)\cr The function to predict newdata. Only needed if \code{model} is not a model from mlr or caret package.}
+#' \item{type: }{(`character(1)`)\cr This argument is passed to the prediction function of the model. The classic use case is to say type="prob" for classification models. 
+#' For example for caret models or the most S3 predict methods. If both predict.fun and type are used, then type is passed as an argument to predict.fun.}
+#' \item{batch.size: }{(`numeric(1)`)\cr The maximum number of rows to be input the model for prediction at once. Currently only respected for FeatureImp, Partial and Interaction.}
 #' }
 #' 
 #' @section Details: 
@@ -59,16 +64,12 @@
 #' if (require("randomForest")) {
 #' rf = randomForest(Species ~ ., data = iris, ntree = 20)
 #' 
-#' # We need this for the randomForest
-#' predict.fun = function(obj, newdata) { 
-#'   predict(obj, newdata = newdata, type = "prob")
-#' }
 #' 
-#' mod = Predictor$new(rf, data = iris, predict.fun = predict.fun)
+#' mod = Predictor$new(rf, data = iris, type = "prob")
 #' mod$predict(iris[50:55,])
 #' 
 #' # Feature importance needs the target vector, which needs to be supplied: 
-#' mod = Predictor$new(rf, data = iris, y = "Species", predict.fun = predict.fun)
+#' mod = Predictor$new(rf, data = iris, y = "Species", type = "prob")
 #' }
 NULL
 
@@ -78,6 +79,7 @@ Predictor = R6::R6Class("Predictor",
   public = list(
     data = NULL,
     model = NULL, 
+    batch.size = NULL,
     predict = function(newdata) {
       checkmate::assert_data_frame(newdata)
       prediction = self$prediction.function(newdata)
@@ -106,7 +108,9 @@ Predictor = R6::R6Class("Predictor",
         cat("Classes: ", paste(self$prediction.colnames, collapse = ", "))
       }
     },
-    initialize = function(model = NULL, data, predict.fun = NULL, y = NULL, class=NULL) {
+    initialize = function(model = NULL, data, predict.fun = NULL, y = NULL, class=NULL, 
+      type = NULL, batch.size = 1000) {
+      assert_number(batch.size, lower = 1)
       if(is.null(model) & is.null(predict.fun)) { 
         stop("Provide a model, a predict.fun or both!")  
       }
@@ -114,7 +118,8 @@ Predictor = R6::R6Class("Predictor",
       self$class = class
       self$model = model
       self$task = inferTaskFromModel(model)
-      self$prediction.function = createPredictionFunction(model, self$task, predict.fun)
+      self$prediction.function = createPredictionFunction(model, self$task, predict.fun, type = type)
+      self$batch.size = batch.size
     }
   ), 
   private = list(
